# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401

from typing import TYPE_CHECKING

import six

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class V1LightningappInstanceSpec(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'app_entrypoint_file': 'str',
        'artifact_storage_uri': 'str',
        'auth': 'V1LightningAuth',
        'can_download_source_code': 'bool',
        'cloud_space_id': 'str',
        'cluster_driver': 'V1LightningappClusterDriver',
        'cluster_id': 'str',
        'compute_config': 'V1ComputeConfig',
        'dependency_cache_key': 'str',
        'desired_state': 'V1LightningappInstanceState',
        'domain': 'str',
        'enable_app_server': 'bool',
        'env': 'list[V1EnvVar]',
        'flow_servers': 'list[V1Flowserver]',
        'image_spec': 'V1ImageSpec',
        'is_app_private': 'bool',
        'is_code_private': 'bool',
        'is_headless': 'bool',
        'network_config': 'list[V1NetworkConfig]',
        'pause_automation': 'bool',
        'queue_server_type': 'V1QueueServerType',
        'redis_token': 'str',
        'release_id': 'str',
        'restart_policy': 'V1LightningappRestartPolicy',
        'should_mount_cloudspace_content': 'bool',
        'source_app': 'str',
        'source_code_url': 'str',
        'user_id': 'str',
        'user_requested_flow_compute_config': 'V1UserRequestedFlowComputeConfig',
        'version': 'str'
    }

    attribute_map = {
        'app_entrypoint_file': 'appEntrypointFile',
        'artifact_storage_uri': 'artifactStorageUri',
        'auth': 'auth',
        'can_download_source_code': 'canDownloadSourceCode',
        'cloud_space_id': 'cloudSpaceId',
        'cluster_driver': 'clusterDriver',
        'cluster_id': 'clusterId',
        'compute_config': 'computeConfig',
        'dependency_cache_key': 'dependencyCacheKey',
        'desired_state': 'desiredState',
        'domain': 'domain',
        'enable_app_server': 'enableAppServer',
        'env': 'env',
        'flow_servers': 'flowServers',
        'image_spec': 'imageSpec',
        'is_app_private': 'isAppPrivate',
        'is_code_private': 'isCodePrivate',
        'is_headless': 'isHeadless',
        'network_config': 'networkConfig',
        'pause_automation': 'pauseAutomation',
        'queue_server_type': 'queueServerType',
        'redis_token': 'redisToken',
        'release_id': 'releaseId',
        'restart_policy': 'restartPolicy',
        'should_mount_cloudspace_content': 'shouldMountCloudspaceContent',
        'source_app': 'sourceApp',
        'source_code_url': 'sourceCodeUrl',
        'user_id': 'userId',
        'user_requested_flow_compute_config': 'userRequestedFlowComputeConfig',
        'version': 'version'
    }

    def __init__(self, app_entrypoint_file: 'str' =None, artifact_storage_uri: 'str' =None, auth: 'V1LightningAuth' =None, can_download_source_code: 'bool' =None, cloud_space_id: 'str' =None, cluster_driver: 'V1LightningappClusterDriver' =None, cluster_id: 'str' =None, compute_config: 'V1ComputeConfig' =None, dependency_cache_key: 'str' =None, desired_state: 'V1LightningappInstanceState' =None, domain: 'str' =None, enable_app_server: 'bool' =None, env: 'list[V1EnvVar]' =None, flow_servers: 'list[V1Flowserver]' =None, image_spec: 'V1ImageSpec' =None, is_app_private: 'bool' =None, is_code_private: 'bool' =None, is_headless: 'bool' =None, network_config: 'list[V1NetworkConfig]' =None, pause_automation: 'bool' =None, queue_server_type: 'V1QueueServerType' =None, redis_token: 'str' =None, release_id: 'str' =None, restart_policy: 'V1LightningappRestartPolicy' =None, should_mount_cloudspace_content: 'bool' =None, source_app: 'str' =None, source_code_url: 'str' =None, user_id: 'str' =None, user_requested_flow_compute_config: 'V1UserRequestedFlowComputeConfig' =None, version: 'str' =None):  # noqa: E501
        """V1LightningappInstanceSpec - a model defined in Swagger"""  # noqa: E501
        self._app_entrypoint_file = None
        self._artifact_storage_uri = None
        self._auth = None
        self._can_download_source_code = None
        self._cloud_space_id = None
        self._cluster_driver = None
        self._cluster_id = None
        self._compute_config = None
        self._dependency_cache_key = None
        self._desired_state = None
        self._domain = None
        self._enable_app_server = None
        self._env = None
        self._flow_servers = None
        self._image_spec = None
        self._is_app_private = None
        self._is_code_private = None
        self._is_headless = None
        self._network_config = None
        self._pause_automation = None
        self._queue_server_type = None
        self._redis_token = None
        self._release_id = None
        self._restart_policy = None
        self._should_mount_cloudspace_content = None
        self._source_app = None
        self._source_code_url = None
        self._user_id = None
        self._user_requested_flow_compute_config = None
        self._version = None
        self.discriminator = None
        if app_entrypoint_file is not None:
            self.app_entrypoint_file = app_entrypoint_file
        if artifact_storage_uri is not None:
            self.artifact_storage_uri = artifact_storage_uri
        if auth is not None:
            self.auth = auth
        if can_download_source_code is not None:
            self.can_download_source_code = can_download_source_code
        if cloud_space_id is not None:
            self.cloud_space_id = cloud_space_id
        if cluster_driver is not None:
            self.cluster_driver = cluster_driver
        if cluster_id is not None:
            self.cluster_id = cluster_id
        if compute_config is not None:
            self.compute_config = compute_config
        if dependency_cache_key is not None:
            self.dependency_cache_key = dependency_cache_key
        if desired_state is not None:
            self.desired_state = desired_state
        if domain is not None:
            self.domain = domain
        if enable_app_server is not None:
            self.enable_app_server = enable_app_server
        if env is not None:
            self.env = env
        if flow_servers is not None:
            self.flow_servers = flow_servers
        if image_spec is not None:
            self.image_spec = image_spec
        if is_app_private is not None:
            self.is_app_private = is_app_private
        if is_code_private is not None:
            self.is_code_private = is_code_private
        if is_headless is not None:
            self.is_headless = is_headless
        if network_config is not None:
            self.network_config = network_config
        if pause_automation is not None:
            self.pause_automation = pause_automation
        if queue_server_type is not None:
            self.queue_server_type = queue_server_type
        if redis_token is not None:
            self.redis_token = redis_token
        if release_id is not None:
            self.release_id = release_id
        if restart_policy is not None:
            self.restart_policy = restart_policy
        if should_mount_cloudspace_content is not None:
            self.should_mount_cloudspace_content = should_mount_cloudspace_content
        if source_app is not None:
            self.source_app = source_app
        if source_code_url is not None:
            self.source_code_url = source_code_url
        if user_id is not None:
            self.user_id = user_id
        if user_requested_flow_compute_config is not None:
            self.user_requested_flow_compute_config = user_requested_flow_compute_config
        if version is not None:
            self.version = version

    @property
    def app_entrypoint_file(self) -> 'str':
        """Gets the app_entrypoint_file of this V1LightningappInstanceSpec.  # noqa: E501


        :return: The app_entrypoint_file of this V1LightningappInstanceSpec.  # noqa: E501
        :rtype: str
        """
        return self._app_entrypoint_file

    @app_entrypoint_file.setter
    def app_entrypoint_file(self, app_entrypoint_file: 'str'):
        """Sets the app_entrypoint_file of this V1LightningappInstanceSpec.


        :param app_entrypoint_file: The app_entrypoint_file of this V1LightningappInstanceSpec.  # noqa: E501
        :type: str
        """

        self._app_entrypoint_file = app_entrypoint_file

    @property
    def artifact_storage_uri(self) -> 'str':
        """Gets the artifact_storage_uri of this V1LightningappInstanceSpec.  # noqa: E501


        :return: The artifact_storage_uri of this V1LightningappInstanceSpec.  # noqa: E501
        :rtype: str
        """
        return self._artifact_storage_uri

    @artifact_storage_uri.setter
    def artifact_storage_uri(self, artifact_storage_uri: 'str'):
        """Sets the artifact_storage_uri of this V1LightningappInstanceSpec.


        :param artifact_storage_uri: The artifact_storage_uri of this V1LightningappInstanceSpec.  # noqa: E501
        :type: str
        """

        self._artifact_storage_uri = artifact_storage_uri

    @property
    def auth(self) -> 'V1LightningAuth':
        """Gets the auth of this V1LightningappInstanceSpec.  # noqa: E501


        :return: The auth of this V1LightningappInstanceSpec.  # noqa: E501
        :rtype: V1LightningAuth
        """
        return self._auth

    @auth.setter
    def auth(self, auth: 'V1LightningAuth'):
        """Sets the auth of this V1LightningappInstanceSpec.


        :param auth: The auth of this V1LightningappInstanceSpec.  # noqa: E501
        :type: V1LightningAuth
        """

        self._auth = auth

    @property
    def can_download_source_code(self) -> 'bool':
        """Gets the can_download_source_code of this V1LightningappInstanceSpec.  # noqa: E501


        :return: The can_download_source_code of this V1LightningappInstanceSpec.  # noqa: E501
        :rtype: bool
        """
        return self._can_download_source_code

    @can_download_source_code.setter
    def can_download_source_code(self, can_download_source_code: 'bool'):
        """Sets the can_download_source_code of this V1LightningappInstanceSpec.


        :param can_download_source_code: The can_download_source_code of this V1LightningappInstanceSpec.  # noqa: E501
        :type: bool
        """

        self._can_download_source_code = can_download_source_code

    @property
    def cloud_space_id(self) -> 'str':
        """Gets the cloud_space_id of this V1LightningappInstanceSpec.  # noqa: E501


        :return: The cloud_space_id of this V1LightningappInstanceSpec.  # noqa: E501
        :rtype: str
        """
        return self._cloud_space_id

    @cloud_space_id.setter
    def cloud_space_id(self, cloud_space_id: 'str'):
        """Sets the cloud_space_id of this V1LightningappInstanceSpec.


        :param cloud_space_id: The cloud_space_id of this V1LightningappInstanceSpec.  # noqa: E501
        :type: str
        """

        self._cloud_space_id = cloud_space_id

    @property
    def cluster_driver(self) -> 'V1LightningappClusterDriver':
        """Gets the cluster_driver of this V1LightningappInstanceSpec.  # noqa: E501


        :return: The cluster_driver of this V1LightningappInstanceSpec.  # noqa: E501
        :rtype: V1LightningappClusterDriver
        """
        return self._cluster_driver

    @cluster_driver.setter
    def cluster_driver(self, cluster_driver: 'V1LightningappClusterDriver'):
        """Sets the cluster_driver of this V1LightningappInstanceSpec.


        :param cluster_driver: The cluster_driver of this V1LightningappInstanceSpec.  # noqa: E501
        :type: V1LightningappClusterDriver
        """

        self._cluster_driver = cluster_driver

    @property
    def cluster_id(self) -> 'str':
        """Gets the cluster_id of this V1LightningappInstanceSpec.  # noqa: E501


        :return: The cluster_id of this V1LightningappInstanceSpec.  # noqa: E501
        :rtype: str
        """
        return self._cluster_id

    @cluster_id.setter
    def cluster_id(self, cluster_id: 'str'):
        """Sets the cluster_id of this V1LightningappInstanceSpec.


        :param cluster_id: The cluster_id of this V1LightningappInstanceSpec.  # noqa: E501
        :type: str
        """

        self._cluster_id = cluster_id

    @property
    def compute_config(self) -> 'V1ComputeConfig':
        """Gets the compute_config of this V1LightningappInstanceSpec.  # noqa: E501


        :return: The compute_config of this V1LightningappInstanceSpec.  # noqa: E501
        :rtype: V1ComputeConfig
        """
        return self._compute_config

    @compute_config.setter
    def compute_config(self, compute_config: 'V1ComputeConfig'):
        """Sets the compute_config of this V1LightningappInstanceSpec.


        :param compute_config: The compute_config of this V1LightningappInstanceSpec.  # noqa: E501
        :type: V1ComputeConfig
        """

        self._compute_config = compute_config

    @property
    def dependency_cache_key(self) -> 'str':
        """Gets the dependency_cache_key of this V1LightningappInstanceSpec.  # noqa: E501


        :return: The dependency_cache_key of this V1LightningappInstanceSpec.  # noqa: E501
        :rtype: str
        """
        return self._dependency_cache_key

    @dependency_cache_key.setter
    def dependency_cache_key(self, dependency_cache_key: 'str'):
        """Sets the dependency_cache_key of this V1LightningappInstanceSpec.


        :param dependency_cache_key: The dependency_cache_key of this V1LightningappInstanceSpec.  # noqa: E501
        :type: str
        """

        self._dependency_cache_key = dependency_cache_key

    @property
    def desired_state(self) -> 'V1LightningappInstanceState':
        """Gets the desired_state of this V1LightningappInstanceSpec.  # noqa: E501


        :return: The desired_state of this V1LightningappInstanceSpec.  # noqa: E501
        :rtype: V1LightningappInstanceState
        """
        return self._desired_state

    @desired_state.setter
    def desired_state(self, desired_state: 'V1LightningappInstanceState'):
        """Sets the desired_state of this V1LightningappInstanceSpec.


        :param desired_state: The desired_state of this V1LightningappInstanceSpec.  # noqa: E501
        :type: V1LightningappInstanceState
        """

        self._desired_state = desired_state

    @property
    def domain(self) -> 'str':
        """Gets the domain of this V1LightningappInstanceSpec.  # noqa: E501

        User-provided custom domain for the app. Will be generated if not provided.  # noqa: E501

        :return: The domain of this V1LightningappInstanceSpec.  # noqa: E501
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain: 'str'):
        """Sets the domain of this V1LightningappInstanceSpec.

        User-provided custom domain for the app. Will be generated if not provided.  # noqa: E501

        :param domain: The domain of this V1LightningappInstanceSpec.  # noqa: E501
        :type: str
        """

        self._domain = domain

    @property
    def enable_app_server(self) -> 'bool':
        """Gets the enable_app_server of this V1LightningappInstanceSpec.  # noqa: E501


        :return: The enable_app_server of this V1LightningappInstanceSpec.  # noqa: E501
        :rtype: bool
        """
        return self._enable_app_server

    @enable_app_server.setter
    def enable_app_server(self, enable_app_server: 'bool'):
        """Sets the enable_app_server of this V1LightningappInstanceSpec.


        :param enable_app_server: The enable_app_server of this V1LightningappInstanceSpec.  # noqa: E501
        :type: bool
        """

        self._enable_app_server = enable_app_server

    @property
    def env(self) -> 'list[V1EnvVar]':
        """Gets the env of this V1LightningappInstanceSpec.  # noqa: E501


        :return: The env of this V1LightningappInstanceSpec.  # noqa: E501
        :rtype: list[V1EnvVar]
        """
        return self._env

    @env.setter
    def env(self, env: 'list[V1EnvVar]'):
        """Sets the env of this V1LightningappInstanceSpec.


        :param env: The env of this V1LightningappInstanceSpec.  # noqa: E501
        :type: list[V1EnvVar]
        """

        self._env = env

    @property
    def flow_servers(self) -> 'list[V1Flowserver]':
        """Gets the flow_servers of this V1LightningappInstanceSpec.  # noqa: E501


        :return: The flow_servers of this V1LightningappInstanceSpec.  # noqa: E501
        :rtype: list[V1Flowserver]
        """
        return self._flow_servers

    @flow_servers.setter
    def flow_servers(self, flow_servers: 'list[V1Flowserver]'):
        """Sets the flow_servers of this V1LightningappInstanceSpec.


        :param flow_servers: The flow_servers of this V1LightningappInstanceSpec.  # noqa: E501
        :type: list[V1Flowserver]
        """

        self._flow_servers = flow_servers

    @property
    def image_spec(self) -> 'V1ImageSpec':
        """Gets the image_spec of this V1LightningappInstanceSpec.  # noqa: E501


        :return: The image_spec of this V1LightningappInstanceSpec.  # noqa: E501
        :rtype: V1ImageSpec
        """
        return self._image_spec

    @image_spec.setter
    def image_spec(self, image_spec: 'V1ImageSpec'):
        """Sets the image_spec of this V1LightningappInstanceSpec.


        :param image_spec: The image_spec of this V1LightningappInstanceSpec.  # noqa: E501
        :type: V1ImageSpec
        """

        self._image_spec = image_spec

    @property
    def is_app_private(self) -> 'bool':
        """Gets the is_app_private of this V1LightningappInstanceSpec.  # noqa: E501


        :return: The is_app_private of this V1LightningappInstanceSpec.  # noqa: E501
        :rtype: bool
        """
        return self._is_app_private

    @is_app_private.setter
    def is_app_private(self, is_app_private: 'bool'):
        """Sets the is_app_private of this V1LightningappInstanceSpec.


        :param is_app_private: The is_app_private of this V1LightningappInstanceSpec.  # noqa: E501
        :type: bool
        """

        self._is_app_private = is_app_private

    @property
    def is_code_private(self) -> 'bool':
        """Gets the is_code_private of this V1LightningappInstanceSpec.  # noqa: E501


        :return: The is_code_private of this V1LightningappInstanceSpec.  # noqa: E501
        :rtype: bool
        """
        return self._is_code_private

    @is_code_private.setter
    def is_code_private(self, is_code_private: 'bool'):
        """Sets the is_code_private of this V1LightningappInstanceSpec.


        :param is_code_private: The is_code_private of this V1LightningappInstanceSpec.  # noqa: E501
        :type: bool
        """

        self._is_code_private = is_code_private

    @property
    def is_headless(self) -> 'bool':
        """Gets the is_headless of this V1LightningappInstanceSpec.  # noqa: E501


        :return: The is_headless of this V1LightningappInstanceSpec.  # noqa: E501
        :rtype: bool
        """
        return self._is_headless

    @is_headless.setter
    def is_headless(self, is_headless: 'bool'):
        """Sets the is_headless of this V1LightningappInstanceSpec.


        :param is_headless: The is_headless of this V1LightningappInstanceSpec.  # noqa: E501
        :type: bool
        """

        self._is_headless = is_headless

    @property
    def network_config(self) -> 'list[V1NetworkConfig]':
        """Gets the network_config of this V1LightningappInstanceSpec.  # noqa: E501


        :return: The network_config of this V1LightningappInstanceSpec.  # noqa: E501
        :rtype: list[V1NetworkConfig]
        """
        return self._network_config

    @network_config.setter
    def network_config(self, network_config: 'list[V1NetworkConfig]'):
        """Sets the network_config of this V1LightningappInstanceSpec.


        :param network_config: The network_config of this V1LightningappInstanceSpec.  # noqa: E501
        :type: list[V1NetworkConfig]
        """

        self._network_config = network_config

    @property
    def pause_automation(self) -> 'bool':
        """Gets the pause_automation of this V1LightningappInstanceSpec.  # noqa: E501


        :return: The pause_automation of this V1LightningappInstanceSpec.  # noqa: E501
        :rtype: bool
        """
        return self._pause_automation

    @pause_automation.setter
    def pause_automation(self, pause_automation: 'bool'):
        """Sets the pause_automation of this V1LightningappInstanceSpec.


        :param pause_automation: The pause_automation of this V1LightningappInstanceSpec.  # noqa: E501
        :type: bool
        """

        self._pause_automation = pause_automation

    @property
    def queue_server_type(self) -> 'V1QueueServerType':
        """Gets the queue_server_type of this V1LightningappInstanceSpec.  # noqa: E501


        :return: The queue_server_type of this V1LightningappInstanceSpec.  # noqa: E501
        :rtype: V1QueueServerType
        """
        return self._queue_server_type

    @queue_server_type.setter
    def queue_server_type(self, queue_server_type: 'V1QueueServerType'):
        """Sets the queue_server_type of this V1LightningappInstanceSpec.


        :param queue_server_type: The queue_server_type of this V1LightningappInstanceSpec.  # noqa: E501
        :type: V1QueueServerType
        """

        self._queue_server_type = queue_server_type

    @property
    def redis_token(self) -> 'str':
        """Gets the redis_token of this V1LightningappInstanceSpec.  # noqa: E501


        :return: The redis_token of this V1LightningappInstanceSpec.  # noqa: E501
        :rtype: str
        """
        return self._redis_token

    @redis_token.setter
    def redis_token(self, redis_token: 'str'):
        """Sets the redis_token of this V1LightningappInstanceSpec.


        :param redis_token: The redis_token of this V1LightningappInstanceSpec.  # noqa: E501
        :type: str
        """

        self._redis_token = redis_token

    @property
    def release_id(self) -> 'str':
        """Gets the release_id of this V1LightningappInstanceSpec.  # noqa: E501


        :return: The release_id of this V1LightningappInstanceSpec.  # noqa: E501
        :rtype: str
        """
        return self._release_id

    @release_id.setter
    def release_id(self, release_id: 'str'):
        """Sets the release_id of this V1LightningappInstanceSpec.


        :param release_id: The release_id of this V1LightningappInstanceSpec.  # noqa: E501
        :type: str
        """

        self._release_id = release_id

    @property
    def restart_policy(self) -> 'V1LightningappRestartPolicy':
        """Gets the restart_policy of this V1LightningappInstanceSpec.  # noqa: E501


        :return: The restart_policy of this V1LightningappInstanceSpec.  # noqa: E501
        :rtype: V1LightningappRestartPolicy
        """
        return self._restart_policy

    @restart_policy.setter
    def restart_policy(self, restart_policy: 'V1LightningappRestartPolicy'):
        """Sets the restart_policy of this V1LightningappInstanceSpec.


        :param restart_policy: The restart_policy of this V1LightningappInstanceSpec.  # noqa: E501
        :type: V1LightningappRestartPolicy
        """

        self._restart_policy = restart_policy

    @property
    def should_mount_cloudspace_content(self) -> 'bool':
        """Gets the should_mount_cloudspace_content of this V1LightningappInstanceSpec.  # noqa: E501


        :return: The should_mount_cloudspace_content of this V1LightningappInstanceSpec.  # noqa: E501
        :rtype: bool
        """
        return self._should_mount_cloudspace_content

    @should_mount_cloudspace_content.setter
    def should_mount_cloudspace_content(self, should_mount_cloudspace_content: 'bool'):
        """Sets the should_mount_cloudspace_content of this V1LightningappInstanceSpec.


        :param should_mount_cloudspace_content: The should_mount_cloudspace_content of this V1LightningappInstanceSpec.  # noqa: E501
        :type: bool
        """

        self._should_mount_cloudspace_content = should_mount_cloudspace_content

    @property
    def source_app(self) -> 'str':
        """Gets the source_app of this V1LightningappInstanceSpec.  # noqa: E501


        :return: The source_app of this V1LightningappInstanceSpec.  # noqa: E501
        :rtype: str
        """
        return self._source_app

    @source_app.setter
    def source_app(self, source_app: 'str'):
        """Sets the source_app of this V1LightningappInstanceSpec.


        :param source_app: The source_app of this V1LightningappInstanceSpec.  # noqa: E501
        :type: str
        """

        self._source_app = source_app

    @property
    def source_code_url(self) -> 'str':
        """Gets the source_code_url of this V1LightningappInstanceSpec.  # noqa: E501


        :return: The source_code_url of this V1LightningappInstanceSpec.  # noqa: E501
        :rtype: str
        """
        return self._source_code_url

    @source_code_url.setter
    def source_code_url(self, source_code_url: 'str'):
        """Sets the source_code_url of this V1LightningappInstanceSpec.


        :param source_code_url: The source_code_url of this V1LightningappInstanceSpec.  # noqa: E501
        :type: str
        """

        self._source_code_url = source_code_url

    @property
    def user_id(self) -> 'str':
        """Gets the user_id of this V1LightningappInstanceSpec.  # noqa: E501


        :return: The user_id of this V1LightningappInstanceSpec.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id: 'str'):
        """Sets the user_id of this V1LightningappInstanceSpec.


        :param user_id: The user_id of this V1LightningappInstanceSpec.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def user_requested_flow_compute_config(self) -> 'V1UserRequestedFlowComputeConfig':
        """Gets the user_requested_flow_compute_config of this V1LightningappInstanceSpec.  # noqa: E501


        :return: The user_requested_flow_compute_config of this V1LightningappInstanceSpec.  # noqa: E501
        :rtype: V1UserRequestedFlowComputeConfig
        """
        return self._user_requested_flow_compute_config

    @user_requested_flow_compute_config.setter
    def user_requested_flow_compute_config(self, user_requested_flow_compute_config: 'V1UserRequestedFlowComputeConfig'):
        """Sets the user_requested_flow_compute_config of this V1LightningappInstanceSpec.


        :param user_requested_flow_compute_config: The user_requested_flow_compute_config of this V1LightningappInstanceSpec.  # noqa: E501
        :type: V1UserRequestedFlowComputeConfig
        """

        self._user_requested_flow_compute_config = user_requested_flow_compute_config

    @property
    def version(self) -> 'str':
        """Gets the version of this V1LightningappInstanceSpec.  # noqa: E501


        :return: The version of this V1LightningappInstanceSpec.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version: 'str'):
        """Sets the version of this V1LightningappInstanceSpec.


        :param version: The version of this V1LightningappInstanceSpec.  # noqa: E501
        :type: str
        """

        self._version = version

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1LightningappInstanceSpec, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'V1LightningappInstanceSpec') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, V1LightningappInstanceSpec):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other: 'V1LightningappInstanceSpec') -> bool:
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401

from typing import TYPE_CHECKING

import six

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class V1LightningappInstanceStatus(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'code_server_url': 'str',
        'dependency_cache_state': 'V1DependencyCacheState',
        'image_id': 'str',
        'ip_address': 'str',
        'last_state_status_transition_timestamp': 'datetime',
        'message': 'str',
        'phase': 'V1LightningappInstanceState',
        'server_id': 'str',
        'source_upload_url': 'str',
        'start_timestamp': 'datetime',
        'stop_timestamp': 'datetime',
        'total_cost': 'float',
        'url': 'str'
    }

    attribute_map = {
        'code_server_url': 'codeServerUrl',
        'dependency_cache_state': 'dependencyCacheState',
        'image_id': 'imageId',
        'ip_address': 'ipAddress',
        'last_state_status_transition_timestamp': 'lastStateStatusTransitionTimestamp',
        'message': 'message',
        'phase': 'phase',
        'server_id': 'serverId',
        'source_upload_url': 'sourceUploadUrl',
        'start_timestamp': 'startTimestamp',
        'stop_timestamp': 'stopTimestamp',
        'total_cost': 'totalCost',
        'url': 'url'
    }

    def __init__(self, code_server_url: 'str' =None, dependency_cache_state: 'V1DependencyCacheState' =None, image_id: 'str' =None, ip_address: 'str' =None, last_state_status_transition_timestamp: 'datetime' =None, message: 'str' =None, phase: 'V1LightningappInstanceState' =None, server_id: 'str' =None, source_upload_url: 'str' =None, start_timestamp: 'datetime' =None, stop_timestamp: 'datetime' =None, total_cost: 'float' =None, url: 'str' =None):  # noqa: E501
        """V1LightningappInstanceStatus - a model defined in Swagger"""  # noqa: E501
        self._code_server_url = None
        self._dependency_cache_state = None
        self._image_id = None
        self._ip_address = None
        self._last_state_status_transition_timestamp = None
        self._message = None
        self._phase = None
        self._server_id = None
        self._source_upload_url = None
        self._start_timestamp = None
        self._stop_timestamp = None
        self._total_cost = None
        self._url = None
        self.discriminator = None
        if code_server_url is not None:
            self.code_server_url = code_server_url
        if dependency_cache_state is not None:
            self.dependency_cache_state = dependency_cache_state
        if image_id is not None:
            self.image_id = image_id
        if ip_address is not None:
            self.ip_address = ip_address
        if last_state_status_transition_timestamp is not None:
            self.last_state_status_transition_timestamp = last_state_status_transition_timestamp
        if message is not None:
            self.message = message
        if phase is not None:
            self.phase = phase
        if server_id is not None:
            self.server_id = server_id
        if source_upload_url is not None:
            self.source_upload_url = source_upload_url
        if start_timestamp is not None:
            self.start_timestamp = start_timestamp
        if stop_timestamp is not None:
            self.stop_timestamp = stop_timestamp
        if total_cost is not None:
            self.total_cost = total_cost
        if url is not None:
            self.url = url

    @property
    def code_server_url(self) -> 'str':
        """Gets the code_server_url of this V1LightningappInstanceStatus.  # noqa: E501


        :return: The code_server_url of this V1LightningappInstanceStatus.  # noqa: E501
        :rtype: str
        """
        return self._code_server_url

    @code_server_url.setter
    def code_server_url(self, code_server_url: 'str'):
        """Sets the code_server_url of this V1LightningappInstanceStatus.


        :param code_server_url: The code_server_url of this V1LightningappInstanceStatus.  # noqa: E501
        :type: str
        """

        self._code_server_url = code_server_url

    @property
    def dependency_cache_state(self) -> 'V1DependencyCacheState':
        """Gets the dependency_cache_state of this V1LightningappInstanceStatus.  # noqa: E501


        :return: The dependency_cache_state of this V1LightningappInstanceStatus.  # noqa: E501
        :rtype: V1DependencyCacheState
        """
        return self._dependency_cache_state

    @dependency_cache_state.setter
    def dependency_cache_state(self, dependency_cache_state: 'V1DependencyCacheState'):
        """Sets the dependency_cache_state of this V1LightningappInstanceStatus.


        :param dependency_cache_state: The dependency_cache_state of this V1LightningappInstanceStatus.  # noqa: E501
        :type: V1DependencyCacheState
        """

        self._dependency_cache_state = dependency_cache_state

    @property
    def image_id(self) -> 'str':
        """Gets the image_id of this V1LightningappInstanceStatus.  # noqa: E501


        :return: The image_id of this V1LightningappInstanceStatus.  # noqa: E501
        :rtype: str
        """
        return self._image_id

    @image_id.setter
    def image_id(self, image_id: 'str'):
        """Sets the image_id of this V1LightningappInstanceStatus.


        :param image_id: The image_id of this V1LightningappInstanceStatus.  # noqa: E501
        :type: str
        """

        self._image_id = image_id

    @property
    def ip_address(self) -> 'str':
        """Gets the ip_address of this V1LightningappInstanceStatus.  # noqa: E501


        :return: The ip_address of this V1LightningappInstanceStatus.  # noqa: E501
        :rtype: str
        """
        return self._ip_address

    @ip_address.setter
    def ip_address(self, ip_address: 'str'):
        """Sets the ip_address of this V1LightningappInstanceStatus.


        :param ip_address: The ip_address of this V1LightningappInstanceStatus.  # noqa: E501
        :type: str
        """

        self._ip_address = ip_address

    @property
    def last_state_status_transition_timestamp(self) -> 'datetime':
        """Gets the last_state_status_transition_timestamp of this V1LightningappInstanceStatus.  # noqa: E501


        :return: The last_state_status_transition_timestamp of this V1LightningappInstanceStatus.  # noqa: E501
        :rtype: datetime
        """
        return self._last_state_status_transition_timestamp

    @last_state_status_transition_timestamp.setter
    def last_state_status_transition_timestamp(self, last_state_status_transition_timestamp: 'datetime'):
        """Sets the last_state_status_transition_timestamp of this V1LightningappInstanceStatus.


        :param last_state_status_transition_timestamp: The last_state_status_transition_timestamp of this V1LightningappInstanceStatus.  # noqa: E501
        :type: datetime
        """

        self._last_state_status_transition_timestamp = last_state_status_transition_timestamp

    @property
    def message(self) -> 'str':
        """Gets the message of this V1LightningappInstanceStatus.  # noqa: E501


        :return: The message of this V1LightningappInstanceStatus.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message: 'str'):
        """Sets the message of this V1LightningappInstanceStatus.


        :param message: The message of this V1LightningappInstanceStatus.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def phase(self) -> 'V1LightningappInstanceState':
        """Gets the phase of this V1LightningappInstanceStatus.  # noqa: E501


        :return: The phase of this V1LightningappInstanceStatus.  # noqa: E501
        :rtype: V1LightningappInstanceState
        """
        return self._phase

    @phase.setter
    def phase(self, phase: 'V1LightningappInstanceState'):
        """Sets the phase of this V1LightningappInstanceStatus.


        :param phase: The phase of this V1LightningappInstanceStatus.  # noqa: E501
        :type: V1LightningappInstanceState
        """

        self._phase = phase

    @property
    def server_id(self) -> 'str':
        """Gets the server_id of this V1LightningappInstanceStatus.  # noqa: E501


        :return: The server_id of this V1LightningappInstanceStatus.  # noqa: E501
        :rtype: str
        """
        return self._server_id

    @server_id.setter
    def server_id(self, server_id: 'str'):
        """Sets the server_id of this V1LightningappInstanceStatus.


        :param server_id: The server_id of this V1LightningappInstanceStatus.  # noqa: E501
        :type: str
        """

        self._server_id = server_id

    @property
    def source_upload_url(self) -> 'str':
        """Gets the source_upload_url of this V1LightningappInstanceStatus.  # noqa: E501


        :return: The source_upload_url of this V1LightningappInstanceStatus.  # noqa: E501
        :rtype: str
        """
        return self._source_upload_url

    @source_upload_url.setter
    def source_upload_url(self, source_upload_url: 'str'):
        """Sets the source_upload_url of this V1LightningappInstanceStatus.


        :param source_upload_url: The source_upload_url of this V1LightningappInstanceStatus.  # noqa: E501
        :type: str
        """

        self._source_upload_url = source_upload_url

    @property
    def start_timestamp(self) -> 'datetime':
        """Gets the start_timestamp of this V1LightningappInstanceStatus.  # noqa: E501


        :return: The start_timestamp of this V1LightningappInstanceStatus.  # noqa: E501
        :rtype: datetime
        """
        return self._start_timestamp

    @start_timestamp.setter
    def start_timestamp(self, start_timestamp: 'datetime'):
        """Sets the start_timestamp of this V1LightningappInstanceStatus.


        :param start_timestamp: The start_timestamp of this V1LightningappInstanceStatus.  # noqa: E501
        :type: datetime
        """

        self._start_timestamp = start_timestamp

    @property
    def stop_timestamp(self) -> 'datetime':
        """Gets the stop_timestamp of this V1LightningappInstanceStatus.  # noqa: E501


        :return: The stop_timestamp of this V1LightningappInstanceStatus.  # noqa: E501
        :rtype: datetime
        """
        return self._stop_timestamp

    @stop_timestamp.setter
    def stop_timestamp(self, stop_timestamp: 'datetime'):
        """Sets the stop_timestamp of this V1LightningappInstanceStatus.


        :param stop_timestamp: The stop_timestamp of this V1LightningappInstanceStatus.  # noqa: E501
        :type: datetime
        """

        self._stop_timestamp = stop_timestamp

    @property
    def total_cost(self) -> 'float':
        """Gets the total_cost of this V1LightningappInstanceStatus.  # noqa: E501


        :return: The total_cost of this V1LightningappInstanceStatus.  # noqa: E501
        :rtype: float
        """
        return self._total_cost

    @total_cost.setter
    def total_cost(self, total_cost: 'float'):
        """Sets the total_cost of this V1LightningappInstanceStatus.


        :param total_cost: The total_cost of this V1LightningappInstanceStatus.  # noqa: E501
        :type: float
        """

        self._total_cost = total_cost

    @property
    def url(self) -> 'str':
        """Gets the url of this V1LightningappInstanceStatus.  # noqa: E501


        :return: The url of this V1LightningappInstanceStatus.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url: 'str'):
        """Sets the url of this V1LightningappInstanceStatus.


        :param url: The url of this V1LightningappInstanceStatus.  # noqa: E501
        :type: str
        """

        self._url = url

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1LightningappInstanceStatus, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'V1LightningappInstanceStatus') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, V1LightningappInstanceStatus):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other: 'V1LightningappInstanceStatus') -> bool:
        """Returns true if both objects are not equal"""
        return not self == other



from typing import Optional, List
import os
from lightning_cloud.rest_client import LightningClient
from lightning_cloud.openapi import (
    ProjectIdDatasetsBody,
    V1DatasetType,
)

def _create_dataset(
    input_dir: str,
    storage_dir: str,
    dataset_type: V1DatasetType,
    empty: Optional[bool] = None,
    size: Optional[int] = None,
    num_bytes: Optional[int] = None,
    data_format: Optional[str] = None,
    compression: Optional[str] = None,
    num_chunks: Optional[str] = None,
    num_bytes_per_chunk: Optional[List[int]] = None,
    name: Optional[str] = None,
    version: Optional[int] = None,
):
    """
    Create a dataset with metadata information about its source and destination
    """
    if input_dir == "":
        raise ValueError("The input_dir should be defined.")

    if storage_dir == "":
        raise ValueError("The storage_dir should be defined.")

    project_id = os.getenv("LIGHTNING_CLOUD_PROJECT_ID", None)
    cluster_id = os.getenv("LIGHTNING_CLUSTER_ID", None)
    user_id = os.getenv("LIGHTNING_USER_ID", None)
    cloud_space_id = os.getenv("LIGHTNING_CLOUD_SPACE_ID", None)
    lightning_app_id = os.getenv("LIGHTNING_CLOUD_APP_ID", None)

    if project_id is None:
        return

    client = LightningClient(retry=False)

    client.dataset_service_create_dataset(
        body=ProjectIdDatasetsBody(
            cloud_space_id=cloud_space_id if lightning_app_id is None else None,
            cluster_id=cluster_id,
            creator_id=user_id,
            empty=empty,
            input_dir=input_dir,
            lightning_app_id=lightning_app_id,
            name=name,
            size=size,
            num_bytes=num_bytes,
            data_format=data_format,
            compression=compression,
            num_chunks=num_chunks,
            num_bytes_per_chunk=num_bytes_per_chunk,
            storage_dir=storage_dir,
            type=dataset_type,
            version=version,
        ),
        project_id=project_id
    )


# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401

from typing import TYPE_CHECKING

import six

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class V1ProjectMembershipInvite(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'invite_reason': 'str',
        'invite_status': 'str',
        'invite_token': 'str',
        'invite_url': 'str',
        'project_id': 'str',
        'role_ids': 'list[str]',
        'user_email': 'str',
        'user_id': 'str'
    }

    attribute_map = {
        'invite_reason': 'inviteReason',
        'invite_status': 'inviteStatus',
        'invite_token': 'inviteToken',
        'invite_url': 'inviteUrl',
        'project_id': 'projectId',
        'role_ids': 'roleIds',
        'user_email': 'userEmail',
        'user_id': 'userId'
    }

    def __init__(self, invite_reason: 'str' =None, invite_status: 'str' =None, invite_token: 'str' =None, invite_url: 'str' =None, project_id: 'str' =None, role_ids: 'list[str]' =None, user_email: 'str' =None, user_id: 'str' =None):  # noqa: E501
        """V1ProjectMembershipInvite - a model defined in Swagger"""  # noqa: E501
        self._invite_reason = None
        self._invite_status = None
        self._invite_token = None
        self._invite_url = None
        self._project_id = None
        self._role_ids = None
        self._user_email = None
        self._user_id = None
        self.discriminator = None
        if invite_reason is not None:
            self.invite_reason = invite_reason
        if invite_status is not None:
            self.invite_status = invite_status
        if invite_token is not None:
            self.invite_token = invite_token
        if invite_url is not None:
            self.invite_url = invite_url
        if project_id is not None:
            self.project_id = project_id
        if role_ids is not None:
            self.role_ids = role_ids
        if user_email is not None:
            self.user_email = user_email
        if user_id is not None:
            self.user_id = user_id

    @property
    def invite_reason(self) -> 'str':
        """Gets the invite_reason of this V1ProjectMembershipInvite.  # noqa: E501


        :return: The invite_reason of this V1ProjectMembershipInvite.  # noqa: E501
        :rtype: str
        """
        return self._invite_reason

    @invite_reason.setter
    def invite_reason(self, invite_reason: 'str'):
        """Sets the invite_reason of this V1ProjectMembershipInvite.


        :param invite_reason: The invite_reason of this V1ProjectMembershipInvite.  # noqa: E501
        :type: str
        """

        self._invite_reason = invite_reason

    @property
    def invite_status(self) -> 'str':
        """Gets the invite_status of this V1ProjectMembershipInvite.  # noqa: E501


        :return: The invite_status of this V1ProjectMembershipInvite.  # noqa: E501
        :rtype: str
        """
        return self._invite_status

    @invite_status.setter
    def invite_status(self, invite_status: 'str'):
        """Sets the invite_status of this V1ProjectMembershipInvite.


        :param invite_status: The invite_status of this V1ProjectMembershipInvite.  # noqa: E501
        :type: str
        """

        self._invite_status = invite_status

    @property
    def invite_token(self) -> 'str':
        """Gets the invite_token of this V1ProjectMembershipInvite.  # noqa: E501


        :return: The invite_token of this V1ProjectMembershipInvite.  # noqa: E501
        :rtype: str
        """
        return self._invite_token

    @invite_token.setter
    def invite_token(self, invite_token: 'str'):
        """Sets the invite_token of this V1ProjectMembershipInvite.


        :param invite_token: The invite_token of this V1ProjectMembershipInvite.  # noqa: E501
        :type: str
        """

        self._invite_token = invite_token

    @property
    def invite_url(self) -> 'str':
        """Gets the invite_url of this V1ProjectMembershipInvite.  # noqa: E501


        :return: The invite_url of this V1ProjectMembershipInvite.  # noqa: E501
        :rtype: str
        """
        return self._invite_url

    @invite_url.setter
    def invite_url(self, invite_url: 'str'):
        """Sets the invite_url of this V1ProjectMembershipInvite.


        :param invite_url: The invite_url of this V1ProjectMembershipInvite.  # noqa: E501
        :type: str
        """

        self._invite_url = invite_url

    @property
    def project_id(self) -> 'str':
        """Gets the project_id of this V1ProjectMembershipInvite.  # noqa: E501


        :return: The project_id of this V1ProjectMembershipInvite.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id: 'str'):
        """Sets the project_id of this V1ProjectMembershipInvite.


        :param project_id: The project_id of this V1ProjectMembershipInvite.  # noqa: E501
        :type: str
        """

        self._project_id = project_id

    @property
    def role_ids(self) -> 'list[str]':
        """Gets the role_ids of this V1ProjectMembershipInvite.  # noqa: E501


        :return: The role_ids of this V1ProjectMembershipInvite.  # noqa: E501
        :rtype: list[str]
        """
        return self._role_ids

    @role_ids.setter
    def role_ids(self, role_ids: 'list[str]'):
        """Sets the role_ids of this V1ProjectMembershipInvite.


        :param role_ids: The role_ids of this V1ProjectMembershipInvite.  # noqa: E501
        :type: list[str]
        """

        self._role_ids = role_ids

    @property
    def user_email(self) -> 'str':
        """Gets the user_email of this V1ProjectMembershipInvite.  # noqa: E501


        :return: The user_email of this V1ProjectMembershipInvite.  # noqa: E501
        :rtype: str
        """
        return self._user_email

    @user_email.setter
    def user_email(self, user_email: 'str'):
        """Sets the user_email of this V1ProjectMembershipInvite.


        :param user_email: The user_email of this V1ProjectMembershipInvite.  # noqa: E501
        :type: str
        """

        self._user_email = user_email

    @property
    def user_id(self) -> 'str':
        """Gets the user_id of this V1ProjectMembershipInvite.  # noqa: E501


        :return: The user_id of this V1ProjectMembershipInvite.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id: 'str'):
        """Sets the user_id of this V1ProjectMembershipInvite.


        :param user_id: The user_id of this V1ProjectMembershipInvite.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1ProjectMembershipInvite, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'V1ProjectMembershipInvite') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, V1ProjectMembershipInvite):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other: 'V1ProjectMembershipInvite') -> bool:
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401

from typing import TYPE_CHECKING

import six

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class V1LightningappInstanceEvent(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'desired_state': 'V1LightningappInstanceState',
        'id': 'str',
        'message': 'str',
        'phase': 'V1LightningappInstanceState',
        'timestamp': 'datetime',
        'total_cost': 'float',
        'work_costs': 'list[V1LightningworkCost]'
    }

    attribute_map = {
        'desired_state': 'desiredState',
        'id': 'id',
        'message': 'message',
        'phase': 'phase',
        'timestamp': 'timestamp',
        'total_cost': 'totalCost',
        'work_costs': 'workCosts'
    }

    def __init__(self, desired_state: 'V1LightningappInstanceState' =None, id: 'str' =None, message: 'str' =None, phase: 'V1LightningappInstanceState' =None, timestamp: 'datetime' =None, total_cost: 'float' =None, work_costs: 'list[V1LightningworkCost]' =None):  # noqa: E501
        """V1LightningappInstanceEvent - a model defined in Swagger"""  # noqa: E501
        self._desired_state = None
        self._id = None
        self._message = None
        self._phase = None
        self._timestamp = None
        self._total_cost = None
        self._work_costs = None
        self.discriminator = None
        if desired_state is not None:
            self.desired_state = desired_state
        if id is not None:
            self.id = id
        if message is not None:
            self.message = message
        if phase is not None:
            self.phase = phase
        if timestamp is not None:
            self.timestamp = timestamp
        if total_cost is not None:
            self.total_cost = total_cost
        if work_costs is not None:
            self.work_costs = work_costs

    @property
    def desired_state(self) -> 'V1LightningappInstanceState':
        """Gets the desired_state of this V1LightningappInstanceEvent.  # noqa: E501


        :return: The desired_state of this V1LightningappInstanceEvent.  # noqa: E501
        :rtype: V1LightningappInstanceState
        """
        return self._desired_state

    @desired_state.setter
    def desired_state(self, desired_state: 'V1LightningappInstanceState'):
        """Sets the desired_state of this V1LightningappInstanceEvent.


        :param desired_state: The desired_state of this V1LightningappInstanceEvent.  # noqa: E501
        :type: V1LightningappInstanceState
        """

        self._desired_state = desired_state

    @property
    def id(self) -> 'str':
        """Gets the id of this V1LightningappInstanceEvent.  # noqa: E501


        :return: The id of this V1LightningappInstanceEvent.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id: 'str'):
        """Sets the id of this V1LightningappInstanceEvent.


        :param id: The id of this V1LightningappInstanceEvent.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def message(self) -> 'str':
        """Gets the message of this V1LightningappInstanceEvent.  # noqa: E501


        :return: The message of this V1LightningappInstanceEvent.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message: 'str'):
        """Sets the message of this V1LightningappInstanceEvent.


        :param message: The message of this V1LightningappInstanceEvent.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def phase(self) -> 'V1LightningappInstanceState':
        """Gets the phase of this V1LightningappInstanceEvent.  # noqa: E501


        :return: The phase of this V1LightningappInstanceEvent.  # noqa: E501
        :rtype: V1LightningappInstanceState
        """
        return self._phase

    @phase.setter
    def phase(self, phase: 'V1LightningappInstanceState'):
        """Sets the phase of this V1LightningappInstanceEvent.


        :param phase: The phase of this V1LightningappInstanceEvent.  # noqa: E501
        :type: V1LightningappInstanceState
        """

        self._phase = phase

    @property
    def timestamp(self) -> 'datetime':
        """Gets the timestamp of this V1LightningappInstanceEvent.  # noqa: E501


        :return: The timestamp of this V1LightningappInstanceEvent.  # noqa: E501
        :rtype: datetime
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp: 'datetime'):
        """Sets the timestamp of this V1LightningappInstanceEvent.


        :param timestamp: The timestamp of this V1LightningappInstanceEvent.  # noqa: E501
        :type: datetime
        """

        self._timestamp = timestamp

    @property
    def total_cost(self) -> 'float':
        """Gets the total_cost of this V1LightningappInstanceEvent.  # noqa: E501


        :return: The total_cost of this V1LightningappInstanceEvent.  # noqa: E501
        :rtype: float
        """
        return self._total_cost

    @total_cost.setter
    def total_cost(self, total_cost: 'float'):
        """Sets the total_cost of this V1LightningappInstanceEvent.


        :param total_cost: The total_cost of this V1LightningappInstanceEvent.  # noqa: E501
        :type: float
        """

        self._total_cost = total_cost

    @property
    def work_costs(self) -> 'list[V1LightningworkCost]':
        """Gets the work_costs of this V1LightningappInstanceEvent.  # noqa: E501


        :return: The work_costs of this V1LightningappInstanceEvent.  # noqa: E501
        :rtype: list[V1LightningworkCost]
        """
        return self._work_costs

    @work_costs.setter
    def work_costs(self, work_costs: 'list[V1LightningworkCost]'):
        """Sets the work_costs of this V1LightningappInstanceEvent.


        :param work_costs: The work_costs of this V1LightningappInstanceEvent.  # noqa: E501
        :type: list[V1LightningworkCost]
        """

        self._work_costs = work_costs

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1LightningappInstanceEvent, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'V1LightningappInstanceEvent') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, V1LightningappInstanceEvent):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other: 'V1LightningappInstanceEvent') -> bool:
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401

from typing import TYPE_CHECKING

import six

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class JobsIdBody(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'message': 'str',
        'slurm_v1_status': 'V1SlurmV1JobStatus',
        'state': 'str',
        'upload_eta_seconds': 'str',
        'upload_in_progress': 'bool',
        'upload_percentage': 'str'
    }

    attribute_map = {
        'message': 'message',
        'slurm_v1_status': 'slurmV1Status',
        'state': 'state',
        'upload_eta_seconds': 'uploadEtaSeconds',
        'upload_in_progress': 'uploadInProgress',
        'upload_percentage': 'uploadPercentage'
    }

    def __init__(self, message: 'str' =None, slurm_v1_status: 'V1SlurmV1JobStatus' =None, state: 'str' =None, upload_eta_seconds: 'str' =None, upload_in_progress: 'bool' =None, upload_percentage: 'str' =None):  # noqa: E501
        """JobsIdBody - a model defined in Swagger"""  # noqa: E501
        self._message = None
        self._slurm_v1_status = None
        self._state = None
        self._upload_eta_seconds = None
        self._upload_in_progress = None
        self._upload_percentage = None
        self.discriminator = None
        if message is not None:
            self.message = message
        if slurm_v1_status is not None:
            self.slurm_v1_status = slurm_v1_status
        if state is not None:
            self.state = state
        if upload_eta_seconds is not None:
            self.upload_eta_seconds = upload_eta_seconds
        if upload_in_progress is not None:
            self.upload_in_progress = upload_in_progress
        if upload_percentage is not None:
            self.upload_percentage = upload_percentage

    @property
    def message(self) -> 'str':
        """Gets the message of this JobsIdBody.  # noqa: E501


        :return: The message of this JobsIdBody.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message: 'str'):
        """Sets the message of this JobsIdBody.


        :param message: The message of this JobsIdBody.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def slurm_v1_status(self) -> 'V1SlurmV1JobStatus':
        """Gets the slurm_v1_status of this JobsIdBody.  # noqa: E501


        :return: The slurm_v1_status of this JobsIdBody.  # noqa: E501
        :rtype: V1SlurmV1JobStatus
        """
        return self._slurm_v1_status

    @slurm_v1_status.setter
    def slurm_v1_status(self, slurm_v1_status: 'V1SlurmV1JobStatus'):
        """Sets the slurm_v1_status of this JobsIdBody.


        :param slurm_v1_status: The slurm_v1_status of this JobsIdBody.  # noqa: E501
        :type: V1SlurmV1JobStatus
        """

        self._slurm_v1_status = slurm_v1_status

    @property
    def state(self) -> 'str':
        """Gets the state of this JobsIdBody.  # noqa: E501


        :return: The state of this JobsIdBody.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state: 'str'):
        """Sets the state of this JobsIdBody.


        :param state: The state of this JobsIdBody.  # noqa: E501
        :type: str
        """

        self._state = state

    @property
    def upload_eta_seconds(self) -> 'str':
        """Gets the upload_eta_seconds of this JobsIdBody.  # noqa: E501


        :return: The upload_eta_seconds of this JobsIdBody.  # noqa: E501
        :rtype: str
        """
        return self._upload_eta_seconds

    @upload_eta_seconds.setter
    def upload_eta_seconds(self, upload_eta_seconds: 'str'):
        """Sets the upload_eta_seconds of this JobsIdBody.


        :param upload_eta_seconds: The upload_eta_seconds of this JobsIdBody.  # noqa: E501
        :type: str
        """

        self._upload_eta_seconds = upload_eta_seconds

    @property
    def upload_in_progress(self) -> 'bool':
        """Gets the upload_in_progress of this JobsIdBody.  # noqa: E501


        :return: The upload_in_progress of this JobsIdBody.  # noqa: E501
        :rtype: bool
        """
        return self._upload_in_progress

    @upload_in_progress.setter
    def upload_in_progress(self, upload_in_progress: 'bool'):
        """Sets the upload_in_progress of this JobsIdBody.


        :param upload_in_progress: The upload_in_progress of this JobsIdBody.  # noqa: E501
        :type: bool
        """

        self._upload_in_progress = upload_in_progress

    @property
    def upload_percentage(self) -> 'str':
        """Gets the upload_percentage of this JobsIdBody.  # noqa: E501


        :return: The upload_percentage of this JobsIdBody.  # noqa: E501
        :rtype: str
        """
        return self._upload_percentage

    @upload_percentage.setter
    def upload_percentage(self, upload_percentage: 'str'):
        """Sets the upload_percentage of this JobsIdBody.


        :param upload_percentage: The upload_percentage of this JobsIdBody.  # noqa: E501
        :type: str
        """

        self._upload_percentage = upload_percentage

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(JobsIdBody, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'JobsIdBody') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, JobsIdBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other: 'JobsIdBody') -> bool:
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

from __future__ import absolute_import

import re  # noqa: F401
from typing import TYPE_CHECKING, Any

# python 2 and python 3 compatibility library
import six

from lightning_cloud.openapi.api_client import ApiClient

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class AgentServiceApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def agent_service_agent_complete_part(self, body: 'object', id: 'str', upload_id: 'str', **kwargs) -> 'V1AgentCompletePartResponse':  # noqa: E501
        """agent_service_agent_complete_part  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.agent_service_agent_complete_part(body, id, upload_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param object body: (required)
        :param str id: (required)
        :param str upload_id: (required)
        :return: V1AgentCompletePartResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.agent_service_agent_complete_part_with_http_info(body, id, upload_id, **kwargs)  # noqa: E501
        else:
            (data) = self.agent_service_agent_complete_part_with_http_info(body, id, upload_id, **kwargs)  # noqa: E501
            return data

    def agent_service_agent_complete_part_with_http_info(self, body: 'object', id: 'str', upload_id: 'str', **kwargs) -> 'V1AgentCompletePartResponse':  # noqa: E501
        """agent_service_agent_complete_part  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.agent_service_agent_complete_part_with_http_info(body, id, upload_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param object body: (required)
        :param str id: (required)
        :param str upload_id: (required)
        :return: V1AgentCompletePartResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'id', 'upload_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method agent_service_agent_complete_part" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `agent_service_agent_complete_part`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `agent_service_agent_complete_part`")  # noqa: E501
        # verify the required parameter 'upload_id' is set
        if ('upload_id' not in params or
                params['upload_id'] is None):
            raise ValueError("Missing the required parameter `upload_id` when calling `agent_service_agent_complete_part`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501
        if 'upload_id' in params:
            path_params['uploadId'] = params['upload_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/agent/jobs/{id}/multipart-uploads/{uploadId}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1AgentCompletePartResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def agent_service_agent_upload_part(self, body: 'MultipartuploadsUploadIdBody', id: 'str', upload_id: 'str', **kwargs) -> 'V1AgentUploadPartResponse':  # noqa: E501
        """agent_service_agent_upload_part  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.agent_service_agent_upload_part(body, id, upload_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param MultipartuploadsUploadIdBody body: (required)
        :param str id: (required)
        :param str upload_id: (required)
        :return: V1AgentUploadPartResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.agent_service_agent_upload_part_with_http_info(body, id, upload_id, **kwargs)  # noqa: E501
        else:
            (data) = self.agent_service_agent_upload_part_with_http_info(body, id, upload_id, **kwargs)  # noqa: E501
            return data

    def agent_service_agent_upload_part_with_http_info(self, body: 'MultipartuploadsUploadIdBody', id: 'str', upload_id: 'str', **kwargs) -> 'V1AgentUploadPartResponse':  # noqa: E501
        """agent_service_agent_upload_part  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.agent_service_agent_upload_part_with_http_info(body, id, upload_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param MultipartuploadsUploadIdBody body: (required)
        :param str id: (required)
        :param str upload_id: (required)
        :return: V1AgentUploadPartResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'id', 'upload_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method agent_service_agent_upload_part" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `agent_service_agent_upload_part`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `agent_service_agent_upload_part`")  # noqa: E501
        # verify the required parameter 'upload_id' is set
        if ('upload_id' not in params or
                params['upload_id'] is None):
            raise ValueError("Missing the required parameter `upload_id` when calling `agent_service_agent_upload_part`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501
        if 'upload_id' in params:
            path_params['uploadId'] = params['upload_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/agent/jobs/{id}/multipart-uploads/{uploadId}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1AgentUploadPartResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def agent_service_create_agent_multipart_upload(self, body: 'IdMultipartuploadsBody', id: 'str', **kwargs) -> 'V1CreateAgentMultipartUploadResponse':  # noqa: E501
        """agent_service_create_agent_multipart_upload  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.agent_service_create_agent_multipart_upload(body, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param IdMultipartuploadsBody body: (required)
        :param str id: (required)
        :return: V1CreateAgentMultipartUploadResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.agent_service_create_agent_multipart_upload_with_http_info(body, id, **kwargs)  # noqa: E501
        else:
            (data) = self.agent_service_create_agent_multipart_upload_with_http_info(body, id, **kwargs)  # noqa: E501
            return data

    def agent_service_create_agent_multipart_upload_with_http_info(self, body: 'IdMultipartuploadsBody', id: 'str', **kwargs) -> 'V1CreateAgentMultipartUploadResponse':  # noqa: E501
        """agent_service_create_agent_multipart_upload  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.agent_service_create_agent_multipart_upload_with_http_info(body, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param IdMultipartuploadsBody body: (required)
        :param str id: (required)
        :return: V1CreateAgentMultipartUploadResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method agent_service_create_agent_multipart_upload" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `agent_service_create_agent_multipart_upload`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `agent_service_create_agent_multipart_upload`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/agent/jobs/{id}/multipart-uploads', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1CreateAgentMultipartUploadResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def agent_service_get_agent_job(self, id: 'str', **kwargs) -> 'V1AgentJob':  # noqa: E501
        """GetAgentJob is used to get a specific agent job for a Lightning AI agent.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.agent_service_get_agent_job(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: V1AgentJob
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.agent_service_get_agent_job_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.agent_service_get_agent_job_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def agent_service_get_agent_job_with_http_info(self, id: 'str', **kwargs) -> 'V1AgentJob':  # noqa: E501
        """GetAgentJob is used to get a specific agent job for a Lightning AI agent.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.agent_service_get_agent_job_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: V1AgentJob
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method agent_service_get_agent_job" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `agent_service_get_agent_job`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/agent/jobs/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1AgentJob',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def agent_service_get_agent_job_env(self, id: 'str', **kwargs) -> 'V1GetAgentJobEnvResponse':  # noqa: E501
        """GetAgentJobEnv returns environment setup (conda env)  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.agent_service_get_agent_job_env(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: V1GetAgentJobEnvResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.agent_service_get_agent_job_env_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.agent_service_get_agent_job_env_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def agent_service_get_agent_job_env_with_http_info(self, id: 'str', **kwargs) -> 'V1GetAgentJobEnvResponse':  # noqa: E501
        """GetAgentJobEnv returns environment setup (conda env)  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.agent_service_get_agent_job_env_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: V1GetAgentJobEnvResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method agent_service_get_agent_job_env" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `agent_service_get_agent_job_env`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/agent/jobs/{id}/env', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1GetAgentJobEnvResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def agent_service_get_agent_job_logs_metadata(self, id: 'str', **kwargs) -> 'V1GetAgentJobLogsMetadataResponse':  # noqa: E501
        """agent_service_get_agent_job_logs_metadata  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.agent_service_get_agent_job_logs_metadata(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param str page_number:
        :return: V1GetAgentJobLogsMetadataResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.agent_service_get_agent_job_logs_metadata_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.agent_service_get_agent_job_logs_metadata_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def agent_service_get_agent_job_logs_metadata_with_http_info(self, id: 'str', **kwargs) -> 'V1GetAgentJobLogsMetadataResponse':  # noqa: E501
        """agent_service_get_agent_job_logs_metadata  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.agent_service_get_agent_job_logs_metadata_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param str page_number:
        :return: V1GetAgentJobLogsMetadataResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'page_number']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method agent_service_get_agent_job_logs_metadata" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `agent_service_get_agent_job_logs_metadata`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'page_number' in params:
            query_params.append(('pageNumber', params['page_number']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/agent/jobs/{id}/logs-metadata', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1GetAgentJobLogsMetadataResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def agent_service_list_agent_job_artifacts(self, id: 'str', **kwargs) -> 'V1ListAgentJobArtifactsResponse':  # noqa: E501
        """Job artifact upload APIs  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.agent_service_list_agent_job_artifacts(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param str prefix:
        :param str page_token:
        :param str page_size:
        :return: V1ListAgentJobArtifactsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.agent_service_list_agent_job_artifacts_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.agent_service_list_agent_job_artifacts_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def agent_service_list_agent_job_artifacts_with_http_info(self, id: 'str', **kwargs) -> 'V1ListAgentJobArtifactsResponse':  # noqa: E501
        """Job artifact upload APIs  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.agent_service_list_agent_job_artifacts_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param str prefix:
        :param str page_token:
        :param str page_size:
        :return: V1ListAgentJobArtifactsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'prefix', 'page_token', 'page_size']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method agent_service_list_agent_job_artifacts" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `agent_service_list_agent_job_artifacts`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'prefix' in params:
            query_params.append(('prefix', params['prefix']))  # noqa: E501
        if 'page_token' in params:
            query_params.append(('pageToken', params['page_token']))  # noqa: E501
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/agent/jobs/{id}/artifacts', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1ListAgentJobArtifactsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def agent_service_list_agent_job_files(self, id: 'str', **kwargs) -> 'V1ListJobFilesResponse':  # noqa: E501
        """ListAgentJobFiles is used to get presigned URLs to download job files. Endpoint returns presigned URLs  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.agent_service_list_agent_job_files(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param str page_token:
        :param str page_size:
        :return: V1ListJobFilesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.agent_service_list_agent_job_files_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.agent_service_list_agent_job_files_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def agent_service_list_agent_job_files_with_http_info(self, id: 'str', **kwargs) -> 'V1ListJobFilesResponse':  # noqa: E501
        """ListAgentJobFiles is used to get presigned URLs to download job files. Endpoint returns presigned URLs  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.agent_service_list_agent_job_files_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param str page_token:
        :param str page_size:
        :return: V1ListJobFilesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'page_token', 'page_size']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method agent_service_list_agent_job_files" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `agent_service_list_agent_job_files`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'page_token' in params:
            query_params.append(('pageToken', params['page_token']))  # noqa: E501
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/agent/jobs/{id}/files', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1ListJobFilesResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def agent_service_list_agent_jobs(self, **kwargs) -> 'V1ListAgentJobsResponse':  # noqa: E501
        """ListAgentJobs is used to list all agent jobs for the currently authetnicated agent.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.agent_service_list_agent_jobs(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[str] state_in:
        :return: V1ListAgentJobsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.agent_service_list_agent_jobs_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.agent_service_list_agent_jobs_with_http_info(**kwargs)  # noqa: E501
            return data

    def agent_service_list_agent_jobs_with_http_info(self, **kwargs) -> 'V1ListAgentJobsResponse':  # noqa: E501
        """ListAgentJobs is used to list all agent jobs for the currently authetnicated agent.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.agent_service_list_agent_jobs_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[str] state_in:
        :return: V1ListAgentJobsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['state_in']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method agent_service_list_agent_jobs" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'state_in' in params:
            query_params.append(('stateIn', params['state_in']))  # noqa: E501
            collection_formats['stateIn'] = 'multi'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/agent/jobs', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1ListAgentJobsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def agent_service_update_agent_job(self, body: 'JobsIdBody', id: 'str', **kwargs) -> 'V1AgentJob':  # noqa: E501
        """UpdateAgentJob is used to update a specific SLURM job for a SLURM agent. For updating SLURM Jobs for a user, please use the SLURMJobsUserService.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.agent_service_update_agent_job(body, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param JobsIdBody body: (required)
        :param str id: (required)
        :return: V1AgentJob
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.agent_service_update_agent_job_with_http_info(body, id, **kwargs)  # noqa: E501
        else:
            (data) = self.agent_service_update_agent_job_with_http_info(body, id, **kwargs)  # noqa: E501
            return data

    def agent_service_update_agent_job_with_http_info(self, body: 'JobsIdBody', id: 'str', **kwargs) -> 'V1AgentJob':  # noqa: E501
        """UpdateAgentJob is used to update a specific SLURM job for a SLURM agent. For updating SLURM Jobs for a user, please use the SLURMJobsUserService.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.agent_service_update_agent_job_with_http_info(body, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param JobsIdBody body: (required)
        :param str id: (required)
        :return: V1AgentJob
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method agent_service_update_agent_job" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `agent_service_update_agent_job`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `agent_service_update_agent_job`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/agent/jobs/{id}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1AgentJob',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def agent_service_update_agent_status(self, body: 'V1UpdateAgentStatusRequest', **kwargs) -> 'V1UpdateAgentStatusResponse':  # noqa: E501
        """agent_service_update_agent_status  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.agent_service_update_agent_status(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param V1UpdateAgentStatusRequest body: (required)
        :return: V1UpdateAgentStatusResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.agent_service_update_agent_status_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.agent_service_update_agent_status_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def agent_service_update_agent_status_with_http_info(self, body: 'V1UpdateAgentStatusRequest', **kwargs) -> 'V1UpdateAgentStatusResponse':  # noqa: E501
        """agent_service_update_agent_status  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.agent_service_update_agent_status_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param V1UpdateAgentStatusRequest body: (required)
        :return: V1UpdateAgentStatusResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method agent_service_update_agent_status" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `agent_service_update_agent_status`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/agent/status', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1UpdateAgentStatusResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def agent_service_upload_agent_job_artifact(self, body: 'IdUploadsBody', id: 'str', **kwargs) -> 'V1UploadAgentJobArtifactResponse':  # noqa: E501
        """agent_service_upload_agent_job_artifact  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.agent_service_upload_agent_job_artifact(body, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param IdUploadsBody body: (required)
        :param str id: (required)
        :return: V1UploadAgentJobArtifactResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.agent_service_upload_agent_job_artifact_with_http_info(body, id, **kwargs)  # noqa: E501
        else:
            (data) = self.agent_service_upload_agent_job_artifact_with_http_info(body, id, **kwargs)  # noqa: E501
            return data

    def agent_service_upload_agent_job_artifact_with_http_info(self, body: 'IdUploadsBody', id: 'str', **kwargs) -> 'V1UploadAgentJobArtifactResponse':  # noqa: E501
        """agent_service_upload_agent_job_artifact  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.agent_service_upload_agent_job_artifact_with_http_info(body, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param IdUploadsBody body: (required)
        :param str id: (required)
        :return: V1UploadAgentJobArtifactResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method agent_service_upload_agent_job_artifact" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `agent_service_upload_agent_job_artifact`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `agent_service_upload_agent_job_artifact`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/agent/jobs/{id}/uploads', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1UploadAgentJobArtifactResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def agent_service_upload_agent_job_output(self, body: 'IdOutputBody', id: 'str', **kwargs) -> 'V1UploadAgentJobOutputResponse':  # noqa: E501
        """TODO: rename to logs  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.agent_service_upload_agent_job_output(body, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param IdOutputBody body: (required)
        :param str id: (required)
        :return: V1UploadAgentJobOutputResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.agent_service_upload_agent_job_output_with_http_info(body, id, **kwargs)  # noqa: E501
        else:
            (data) = self.agent_service_upload_agent_job_output_with_http_info(body, id, **kwargs)  # noqa: E501
            return data

    def agent_service_upload_agent_job_output_with_http_info(self, body: 'IdOutputBody', id: 'str', **kwargs) -> 'V1UploadAgentJobOutputResponse':  # noqa: E501
        """TODO: rename to logs  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.agent_service_upload_agent_job_output_with_http_info(body, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param IdOutputBody body: (required)
        :param str id: (required)
        :return: V1UploadAgentJobOutputResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method agent_service_upload_agent_job_output" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `agent_service_upload_agent_job_output`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `agent_service_upload_agent_job_output`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/agent/jobs/{id}/output', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1UploadAgentJobOutputResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401

from typing import TYPE_CHECKING

import six

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class V1PublishedCloudSpaceResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'cluster_id': 'str',
        'creation_timestamp': 'datetime',
        'description': 'str',
        'display_name': 'str',
        'engagement_counts': 'dict(str, str)',
        'id': 'str',
        'name': 'str',
        'project_id': 'str',
        'project_name': 'str',
        'project_owner_name': 'str',
        'published_at': 'datetime',
        'studio_creator_username': 'str',
        'tags': 'list[V1CloudSpaceTag]',
        'thumbnail_url': 'str'
    }

    attribute_map = {
        'cluster_id': 'clusterId',
        'creation_timestamp': 'creationTimestamp',
        'description': 'description',
        'display_name': 'displayName',
        'engagement_counts': 'engagementCounts',
        'id': 'id',
        'name': 'name',
        'project_id': 'projectId',
        'project_name': 'projectName',
        'project_owner_name': 'projectOwnerName',
        'published_at': 'publishedAt',
        'studio_creator_username': 'studioCreatorUsername',
        'tags': 'tags',
        'thumbnail_url': 'thumbnailUrl'
    }

    def __init__(self, cluster_id: 'str' =None, creation_timestamp: 'datetime' =None, description: 'str' =None, display_name: 'str' =None, engagement_counts: 'dict(str, str)' =None, id: 'str' =None, name: 'str' =None, project_id: 'str' =None, project_name: 'str' =None, project_owner_name: 'str' =None, published_at: 'datetime' =None, studio_creator_username: 'str' =None, tags: 'list[V1CloudSpaceTag]' =None, thumbnail_url: 'str' =None):  # noqa: E501
        """V1PublishedCloudSpaceResponse - a model defined in Swagger"""  # noqa: E501
        self._cluster_id = None
        self._creation_timestamp = None
        self._description = None
        self._display_name = None
        self._engagement_counts = None
        self._id = None
        self._name = None
        self._project_id = None
        self._project_name = None
        self._project_owner_name = None
        self._published_at = None
        self._studio_creator_username = None
        self._tags = None
        self._thumbnail_url = None
        self.discriminator = None
        if cluster_id is not None:
            self.cluster_id = cluster_id
        if creation_timestamp is not None:
            self.creation_timestamp = creation_timestamp
        if description is not None:
            self.description = description
        if display_name is not None:
            self.display_name = display_name
        if engagement_counts is not None:
            self.engagement_counts = engagement_counts
        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if project_id is not None:
            self.project_id = project_id
        if project_name is not None:
            self.project_name = project_name
        if project_owner_name is not None:
            self.project_owner_name = project_owner_name
        if published_at is not None:
            self.published_at = published_at
        if studio_creator_username is not None:
            self.studio_creator_username = studio_creator_username
        if tags is not None:
            self.tags = tags
        if thumbnail_url is not None:
            self.thumbnail_url = thumbnail_url

    @property
    def cluster_id(self) -> 'str':
        """Gets the cluster_id of this V1PublishedCloudSpaceResponse.  # noqa: E501


        :return: The cluster_id of this V1PublishedCloudSpaceResponse.  # noqa: E501
        :rtype: str
        """
        return self._cluster_id

    @cluster_id.setter
    def cluster_id(self, cluster_id: 'str'):
        """Sets the cluster_id of this V1PublishedCloudSpaceResponse.


        :param cluster_id: The cluster_id of this V1PublishedCloudSpaceResponse.  # noqa: E501
        :type: str
        """

        self._cluster_id = cluster_id

    @property
    def creation_timestamp(self) -> 'datetime':
        """Gets the creation_timestamp of this V1PublishedCloudSpaceResponse.  # noqa: E501


        :return: The creation_timestamp of this V1PublishedCloudSpaceResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._creation_timestamp

    @creation_timestamp.setter
    def creation_timestamp(self, creation_timestamp: 'datetime'):
        """Sets the creation_timestamp of this V1PublishedCloudSpaceResponse.


        :param creation_timestamp: The creation_timestamp of this V1PublishedCloudSpaceResponse.  # noqa: E501
        :type: datetime
        """

        self._creation_timestamp = creation_timestamp

    @property
    def description(self) -> 'str':
        """Gets the description of this V1PublishedCloudSpaceResponse.  # noqa: E501


        :return: The description of this V1PublishedCloudSpaceResponse.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description: 'str'):
        """Sets the description of this V1PublishedCloudSpaceResponse.


        :param description: The description of this V1PublishedCloudSpaceResponse.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def display_name(self) -> 'str':
        """Gets the display_name of this V1PublishedCloudSpaceResponse.  # noqa: E501


        :return: The display_name of this V1PublishedCloudSpaceResponse.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name: 'str'):
        """Sets the display_name of this V1PublishedCloudSpaceResponse.


        :param display_name: The display_name of this V1PublishedCloudSpaceResponse.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def engagement_counts(self) -> 'dict(str, str)':
        """Gets the engagement_counts of this V1PublishedCloudSpaceResponse.  # noqa: E501


        :return: The engagement_counts of this V1PublishedCloudSpaceResponse.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._engagement_counts

    @engagement_counts.setter
    def engagement_counts(self, engagement_counts: 'dict(str, str)'):
        """Sets the engagement_counts of this V1PublishedCloudSpaceResponse.


        :param engagement_counts: The engagement_counts of this V1PublishedCloudSpaceResponse.  # noqa: E501
        :type: dict(str, str)
        """

        self._engagement_counts = engagement_counts

    @property
    def id(self) -> 'str':
        """Gets the id of this V1PublishedCloudSpaceResponse.  # noqa: E501


        :return: The id of this V1PublishedCloudSpaceResponse.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id: 'str'):
        """Sets the id of this V1PublishedCloudSpaceResponse.


        :param id: The id of this V1PublishedCloudSpaceResponse.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self) -> 'str':
        """Gets the name of this V1PublishedCloudSpaceResponse.  # noqa: E501


        :return: The name of this V1PublishedCloudSpaceResponse.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name: 'str'):
        """Sets the name of this V1PublishedCloudSpaceResponse.


        :param name: The name of this V1PublishedCloudSpaceResponse.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def project_id(self) -> 'str':
        """Gets the project_id of this V1PublishedCloudSpaceResponse.  # noqa: E501


        :return: The project_id of this V1PublishedCloudSpaceResponse.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id: 'str'):
        """Sets the project_id of this V1PublishedCloudSpaceResponse.


        :param project_id: The project_id of this V1PublishedCloudSpaceResponse.  # noqa: E501
        :type: str
        """

        self._project_id = project_id

    @property
    def project_name(self) -> 'str':
        """Gets the project_name of this V1PublishedCloudSpaceResponse.  # noqa: E501


        :return: The project_name of this V1PublishedCloudSpaceResponse.  # noqa: E501
        :rtype: str
        """
        return self._project_name

    @project_name.setter
    def project_name(self, project_name: 'str'):
        """Sets the project_name of this V1PublishedCloudSpaceResponse.


        :param project_name: The project_name of this V1PublishedCloudSpaceResponse.  # noqa: E501
        :type: str
        """

        self._project_name = project_name

    @property
    def project_owner_name(self) -> 'str':
        """Gets the project_owner_name of this V1PublishedCloudSpaceResponse.  # noqa: E501


        :return: The project_owner_name of this V1PublishedCloudSpaceResponse.  # noqa: E501
        :rtype: str
        """
        return self._project_owner_name

    @project_owner_name.setter
    def project_owner_name(self, project_owner_name: 'str'):
        """Sets the project_owner_name of this V1PublishedCloudSpaceResponse.


        :param project_owner_name: The project_owner_name of this V1PublishedCloudSpaceResponse.  # noqa: E501
        :type: str
        """

        self._project_owner_name = project_owner_name

    @property
    def published_at(self) -> 'datetime':
        """Gets the published_at of this V1PublishedCloudSpaceResponse.  # noqa: E501


        :return: The published_at of this V1PublishedCloudSpaceResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._published_at

    @published_at.setter
    def published_at(self, published_at: 'datetime'):
        """Sets the published_at of this V1PublishedCloudSpaceResponse.


        :param published_at: The published_at of this V1PublishedCloudSpaceResponse.  # noqa: E501
        :type: datetime
        """

        self._published_at = published_at

    @property
    def studio_creator_username(self) -> 'str':
        """Gets the studio_creator_username of this V1PublishedCloudSpaceResponse.  # noqa: E501


        :return: The studio_creator_username of this V1PublishedCloudSpaceResponse.  # noqa: E501
        :rtype: str
        """
        return self._studio_creator_username

    @studio_creator_username.setter
    def studio_creator_username(self, studio_creator_username: 'str'):
        """Sets the studio_creator_username of this V1PublishedCloudSpaceResponse.


        :param studio_creator_username: The studio_creator_username of this V1PublishedCloudSpaceResponse.  # noqa: E501
        :type: str
        """

        self._studio_creator_username = studio_creator_username

    @property
    def tags(self) -> 'list[V1CloudSpaceTag]':
        """Gets the tags of this V1PublishedCloudSpaceResponse.  # noqa: E501


        :return: The tags of this V1PublishedCloudSpaceResponse.  # noqa: E501
        :rtype: list[V1CloudSpaceTag]
        """
        return self._tags

    @tags.setter
    def tags(self, tags: 'list[V1CloudSpaceTag]'):
        """Sets the tags of this V1PublishedCloudSpaceResponse.


        :param tags: The tags of this V1PublishedCloudSpaceResponse.  # noqa: E501
        :type: list[V1CloudSpaceTag]
        """

        self._tags = tags

    @property
    def thumbnail_url(self) -> 'str':
        """Gets the thumbnail_url of this V1PublishedCloudSpaceResponse.  # noqa: E501


        :return: The thumbnail_url of this V1PublishedCloudSpaceResponse.  # noqa: E501
        :rtype: str
        """
        return self._thumbnail_url

    @thumbnail_url.setter
    def thumbnail_url(self, thumbnail_url: 'str'):
        """Sets the thumbnail_url of this V1PublishedCloudSpaceResponse.


        :param thumbnail_url: The thumbnail_url of this V1PublishedCloudSpaceResponse.  # noqa: E501
        :type: str
        """

        self._thumbnail_url = thumbnail_url

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1PublishedCloudSpaceResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'V1PublishedCloudSpaceResponse') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, V1PublishedCloudSpaceResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other: 'V1PublishedCloudSpaceResponse') -> bool:
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401

from typing import TYPE_CHECKING

import six

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class V1GetProjectBalanceResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'account_id': 'str',
        'balance': 'float',
        'project_id': 'str',
        'top_ups': 'list[V1TopUp]',
        'transfers': 'list[V1Transfer]'
    }

    attribute_map = {
        'account_id': 'accountId',
        'balance': 'balance',
        'project_id': 'projectId',
        'top_ups': 'topUps',
        'transfers': 'transfers'
    }

    def __init__(self, account_id: 'str' =None, balance: 'float' =None, project_id: 'str' =None, top_ups: 'list[V1TopUp]' =None, transfers: 'list[V1Transfer]' =None):  # noqa: E501
        """V1GetProjectBalanceResponse - a model defined in Swagger"""  # noqa: E501
        self._account_id = None
        self._balance = None
        self._project_id = None
        self._top_ups = None
        self._transfers = None
        self.discriminator = None
        if account_id is not None:
            self.account_id = account_id
        if balance is not None:
            self.balance = balance
        if project_id is not None:
            self.project_id = project_id
        if top_ups is not None:
            self.top_ups = top_ups
        if transfers is not None:
            self.transfers = transfers

    @property
    def account_id(self) -> 'str':
        """Gets the account_id of this V1GetProjectBalanceResponse.  # noqa: E501


        :return: The account_id of this V1GetProjectBalanceResponse.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id: 'str'):
        """Sets the account_id of this V1GetProjectBalanceResponse.


        :param account_id: The account_id of this V1GetProjectBalanceResponse.  # noqa: E501
        :type: str
        """

        self._account_id = account_id

    @property
    def balance(self) -> 'float':
        """Gets the balance of this V1GetProjectBalanceResponse.  # noqa: E501


        :return: The balance of this V1GetProjectBalanceResponse.  # noqa: E501
        :rtype: float
        """
        return self._balance

    @balance.setter
    def balance(self, balance: 'float'):
        """Sets the balance of this V1GetProjectBalanceResponse.


        :param balance: The balance of this V1GetProjectBalanceResponse.  # noqa: E501
        :type: float
        """

        self._balance = balance

    @property
    def project_id(self) -> 'str':
        """Gets the project_id of this V1GetProjectBalanceResponse.  # noqa: E501


        :return: The project_id of this V1GetProjectBalanceResponse.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id: 'str'):
        """Sets the project_id of this V1GetProjectBalanceResponse.


        :param project_id: The project_id of this V1GetProjectBalanceResponse.  # noqa: E501
        :type: str
        """

        self._project_id = project_id

    @property
    def top_ups(self) -> 'list[V1TopUp]':
        """Gets the top_ups of this V1GetProjectBalanceResponse.  # noqa: E501


        :return: The top_ups of this V1GetProjectBalanceResponse.  # noqa: E501
        :rtype: list[V1TopUp]
        """
        return self._top_ups

    @top_ups.setter
    def top_ups(self, top_ups: 'list[V1TopUp]'):
        """Sets the top_ups of this V1GetProjectBalanceResponse.


        :param top_ups: The top_ups of this V1GetProjectBalanceResponse.  # noqa: E501
        :type: list[V1TopUp]
        """

        self._top_ups = top_ups

    @property
    def transfers(self) -> 'list[V1Transfer]':
        """Gets the transfers of this V1GetProjectBalanceResponse.  # noqa: E501


        :return: The transfers of this V1GetProjectBalanceResponse.  # noqa: E501
        :rtype: list[V1Transfer]
        """
        return self._transfers

    @transfers.setter
    def transfers(self, transfers: 'list[V1Transfer]'):
        """Sets the transfers of this V1GetProjectBalanceResponse.


        :param transfers: The transfers of this V1GetProjectBalanceResponse.  # noqa: E501
        :type: list[V1Transfer]
        """

        self._transfers = transfers

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1GetProjectBalanceResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'V1GetProjectBalanceResponse') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, V1GetProjectBalanceResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other: 'V1GetProjectBalanceResponse') -> bool:
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401

from typing import TYPE_CHECKING

import six

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class V1AWSClusterSecondaryRegionSpec(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'az_names': 'list[str]',
        'ec2_cpu_ami': 'str',
        'ec2_cpu_ami_cloud_space': 'str',
        'ec2_gpu_ami': 'str',
        'ec2_gpu_ami_cloud_space': 'str',
        'region': 'str'
    }

    attribute_map = {
        'az_names': 'azNames',
        'ec2_cpu_ami': 'ec2CpuAmi',
        'ec2_cpu_ami_cloud_space': 'ec2CpuAmiCloudSpace',
        'ec2_gpu_ami': 'ec2GpuAmi',
        'ec2_gpu_ami_cloud_space': 'ec2GpuAmiCloudSpace',
        'region': 'region'
    }

    def __init__(self, az_names: 'list[str]' =None, ec2_cpu_ami: 'str' =None, ec2_cpu_ami_cloud_space: 'str' =None, ec2_gpu_ami: 'str' =None, ec2_gpu_ami_cloud_space: 'str' =None, region: 'str' =None):  # noqa: E501
        """V1AWSClusterSecondaryRegionSpec - a model defined in Swagger"""  # noqa: E501
        self._az_names = None
        self._ec2_cpu_ami = None
        self._ec2_cpu_ami_cloud_space = None
        self._ec2_gpu_ami = None
        self._ec2_gpu_ami_cloud_space = None
        self._region = None
        self.discriminator = None
        if az_names is not None:
            self.az_names = az_names
        if ec2_cpu_ami is not None:
            self.ec2_cpu_ami = ec2_cpu_ami
        if ec2_cpu_ami_cloud_space is not None:
            self.ec2_cpu_ami_cloud_space = ec2_cpu_ami_cloud_space
        if ec2_gpu_ami is not None:
            self.ec2_gpu_ami = ec2_gpu_ami
        if ec2_gpu_ami_cloud_space is not None:
            self.ec2_gpu_ami_cloud_space = ec2_gpu_ami_cloud_space
        if region is not None:
            self.region = region

    @property
    def az_names(self) -> 'list[str]':
        """Gets the az_names of this V1AWSClusterSecondaryRegionSpec.  # noqa: E501


        :return: The az_names of this V1AWSClusterSecondaryRegionSpec.  # noqa: E501
        :rtype: list[str]
        """
        return self._az_names

    @az_names.setter
    def az_names(self, az_names: 'list[str]'):
        """Sets the az_names of this V1AWSClusterSecondaryRegionSpec.


        :param az_names: The az_names of this V1AWSClusterSecondaryRegionSpec.  # noqa: E501
        :type: list[str]
        """

        self._az_names = az_names

    @property
    def ec2_cpu_ami(self) -> 'str':
        """Gets the ec2_cpu_ami of this V1AWSClusterSecondaryRegionSpec.  # noqa: E501


        :return: The ec2_cpu_ami of this V1AWSClusterSecondaryRegionSpec.  # noqa: E501
        :rtype: str
        """
        return self._ec2_cpu_ami

    @ec2_cpu_ami.setter
    def ec2_cpu_ami(self, ec2_cpu_ami: 'str'):
        """Sets the ec2_cpu_ami of this V1AWSClusterSecondaryRegionSpec.


        :param ec2_cpu_ami: The ec2_cpu_ami of this V1AWSClusterSecondaryRegionSpec.  # noqa: E501
        :type: str
        """

        self._ec2_cpu_ami = ec2_cpu_ami

    @property
    def ec2_cpu_ami_cloud_space(self) -> 'str':
        """Gets the ec2_cpu_ami_cloud_space of this V1AWSClusterSecondaryRegionSpec.  # noqa: E501


        :return: The ec2_cpu_ami_cloud_space of this V1AWSClusterSecondaryRegionSpec.  # noqa: E501
        :rtype: str
        """
        return self._ec2_cpu_ami_cloud_space

    @ec2_cpu_ami_cloud_space.setter
    def ec2_cpu_ami_cloud_space(self, ec2_cpu_ami_cloud_space: 'str'):
        """Sets the ec2_cpu_ami_cloud_space of this V1AWSClusterSecondaryRegionSpec.


        :param ec2_cpu_ami_cloud_space: The ec2_cpu_ami_cloud_space of this V1AWSClusterSecondaryRegionSpec.  # noqa: E501
        :type: str
        """

        self._ec2_cpu_ami_cloud_space = ec2_cpu_ami_cloud_space

    @property
    def ec2_gpu_ami(self) -> 'str':
        """Gets the ec2_gpu_ami of this V1AWSClusterSecondaryRegionSpec.  # noqa: E501


        :return: The ec2_gpu_ami of this V1AWSClusterSecondaryRegionSpec.  # noqa: E501
        :rtype: str
        """
        return self._ec2_gpu_ami

    @ec2_gpu_ami.setter
    def ec2_gpu_ami(self, ec2_gpu_ami: 'str'):
        """Sets the ec2_gpu_ami of this V1AWSClusterSecondaryRegionSpec.


        :param ec2_gpu_ami: The ec2_gpu_ami of this V1AWSClusterSecondaryRegionSpec.  # noqa: E501
        :type: str
        """

        self._ec2_gpu_ami = ec2_gpu_ami

    @property
    def ec2_gpu_ami_cloud_space(self) -> 'str':
        """Gets the ec2_gpu_ami_cloud_space of this V1AWSClusterSecondaryRegionSpec.  # noqa: E501


        :return: The ec2_gpu_ami_cloud_space of this V1AWSClusterSecondaryRegionSpec.  # noqa: E501
        :rtype: str
        """
        return self._ec2_gpu_ami_cloud_space

    @ec2_gpu_ami_cloud_space.setter
    def ec2_gpu_ami_cloud_space(self, ec2_gpu_ami_cloud_space: 'str'):
        """Sets the ec2_gpu_ami_cloud_space of this V1AWSClusterSecondaryRegionSpec.


        :param ec2_gpu_ami_cloud_space: The ec2_gpu_ami_cloud_space of this V1AWSClusterSecondaryRegionSpec.  # noqa: E501
        :type: str
        """

        self._ec2_gpu_ami_cloud_space = ec2_gpu_ami_cloud_space

    @property
    def region(self) -> 'str':
        """Gets the region of this V1AWSClusterSecondaryRegionSpec.  # noqa: E501


        :return: The region of this V1AWSClusterSecondaryRegionSpec.  # noqa: E501
        :rtype: str
        """
        return self._region

    @region.setter
    def region(self, region: 'str'):
        """Sets the region of this V1AWSClusterSecondaryRegionSpec.


        :param region: The region of this V1AWSClusterSecondaryRegionSpec.  # noqa: E501
        :type: str
        """

        self._region = region

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1AWSClusterSecondaryRegionSpec, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'V1AWSClusterSecondaryRegionSpec') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, V1AWSClusterSecondaryRegionSpec):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other: 'V1AWSClusterSecondaryRegionSpec') -> bool:
        """Returns true if both objects are not equal"""
        return not self == other
